@@ -3,8 +3,14 @@
 
 #include <QMainWindow>
 #include <QDomDocument>
-#include "commonIncludes.h"
+#include <QSignalMapper>
+#include <QNetworkAccessManager>
+#include <QNetworkRequest>
+#include <QNetworkReply>
+#include <QResizeEvent>
+#include <QUrl>
 #include "progressdialog.h"
+#include "stackedwindow.h"
 #include "dayperiod.h"
 
 namespace Ui {
@@ -22,9 +28,39 @@ public:
 protected:
     virtual void resizeEvent(QResizeEvent * event);
 
+signals:
+    void uiReady();
+
+private:
+    Ui::MainWindow *ui;
+    QDomDocument *doc;
+    QNetworkAccessManager *manager;
+    QSignalMapper* mapper;
+    QString zipCode;
+    QString zipCache;
+    QString *latlon;
+    QString *wfo;
+    QString *zcode;
+    QList<DayPeriod*>* dayPeriods;
+    QPixmap** iconCache; //array of icon pointers
+    QIcon *icon;
+    int iconCount;
+    bool needShowList;
+    ProgressDialog *pg;
+
+    void detailWindow(int day);
+    void setDomDocument(QString* reply);
+    void deleteCache();
+    QList<QString*>* parse_for_temps(QDomElement* domElement);
+    QList<QString*>* parse_for_days(QDomElement* domElement);
+    QString* parse_for_city(QDomElement* domElement);
+
 private slots:
-    void replyFinished(QNetworkReply *reply);
-    void setFIcon(QNetworkReply *reply);
+    void gotCoordinates();
+    void gotXML();
+    void setDayIcons(int dayIndex);
+    void setFIcon();
+
     void dayClick(QModelIndex index);
     void changeZip();
     void visitNAOO();
@@ -32,31 +68,6 @@ private slots:
         changeZip();
     }
 
-signals:
-    void uiReady();
-
-
-
-private:
-    Ui::MainWindow *ui;
-    QDomDocument *doc;
-    QNetworkAccessManager *manager;
-    QString zipCode;
-    QString zipCache;
-    QString *latlon;
-    QString *wfo;
-    QString *zcode;
-    QList<QString*> *iconURLs;
-    QList<DayPeriod*> *dayPeriods;
-    QIcon *icon;
-    int iconCount;
-    bool needCoords;
-    bool needShowList;
-    ProgressDialog *pg;
-
-    void detailWindow(int day);
-    void setDomDocument(QString* reply);
-
 
 };
 
